# numberwords.py
# --------------
# By MWC Contributors
# Functions to print out a verbal representation of an integer.

MAXIMUM = 1000000
DIGIT_NAMES = [
    "zero", "one", "two", "three", "four", "five", "six", "seven", "eight", "nine"
]
TWEEN_AND_TEEN_NAMES = [
    "ten", "eleven", "twelve", "thirteen", "fourteen", "fifteen", "sixteen", "seventeen", "eighteen", "nineteen"
]
TENS_NAMES = [
    "ten", "twenty", "thirty", "forty", "fifty", "sixty", "seventy", "eighty", "ninety"
]

def int_under_1000000_to_str(number):
    "Returns a textual representation of the number."
    check_number_in_range(abs(number), 0, MAXIMUM)
    if number < 1000:
        return int_under_1000_to_str(number)
    else:
        thousands, hundreds = divide_with_remainder(number, 1000)
        thousands_text = int_under_1000_to_str(thousands)
        hundreds_text = int_under_1000_to_str(hundreds)
        return thousands_text + " thousand " + hundreds_text
        
def int_under_1000_to_str(number):
    "Returns a textual representation of the number"
    check_number_in_range(number, 0, 1000)
    if number < 100:
        return int_under_100_to_str(number)
    else:
        hundreds, tens = divide_with_remainder(number, 100)
        hundreds_text = int_under_10_to_str(hundreds)
        tens_text = int_under_100_to_str(tens)
        return hundreds_text + " hundred and " + tens_text

def int_under_100_to_str(number):
    check_number_in_range(number, 0, 100)
    tens, ones = divide_with_remainder(number, 10)
    if tens == 0:
        return int_under_10_to_str(number)
    elif tens == 1:
        return TWEEN_AND_TEEN_NAMES[ones]
    else:
        return TENS_NAMES[tens] + '-' + int_under_10_to_str(ones)

def int_under_10_to_str(number):
    check_number_in_range(number, 0, 10)
    return DIGIT_NAMES[number]

def check_number_in_range(number, minimum, maximum):
    """Checks whether a number is at least minimum and less than maximum. 
    Raises an error if the number is not in range.
    """
    if number < minimum:
        raise ValueError(f"{number} must not be below {minimum}.")
    if number >= maximum:
        raise ValueError(f"{number} must be less than {maximum}.")

def divide_with_remainder(dividend, divisor):
    """Divides one number by another, using whole-number division. 
    Returns the quotient and the remainder.
    Note how a function can return more than one value!
    """
    quotient = dividend // divisor
    remainder = dividend % divisor
    return quotient, remainder
